# yapstone-payments

Yapstone - the Ruby gem for the Payments Orchestrator

\"REST API for Payments Orchestrator\"

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6.4-SNAPSHOT
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build yapstone-payments.gemspec
```

Then either install the gem locally:

```shell
gem install ./yapstone-payments-1.0.0.gem
```

(for development, run `gem install --dev ./yapstone-payments-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'yapstone-payments', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'yapstone-payments', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'yapstone-payments'

api_instance = Yapstone::AuthenticationApi.new
grant_type = 'client_credentials' # String | To do OAuth2 authentication, you must indicate the grant type, then adhere to it structurally. Yapstone API endpoints authenticate with OAuth2 and the grant type client credentials. This type of authentication is used to access resources on your own system rather than access a user's resources. 
authorization = 'Basic SGxkdU5OcU1xMzBUZ0djYUpDWVpIWVRsejJjQUJlSHo6YkdIeWNpWXVibzNVTXZLRA==' # String | Provide client_id:client_secret as base64 encoded basic auth. 

begin
  #Authenticate Partner
  result = api_instance.authenticate_partner(grant_type, authorization)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling AuthenticationApi->authenticate_partner: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api-prod-sandbox.yapstone.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Yapstone::AuthenticationApi* | [**authenticate_partner**](docs/AuthenticationApi.md#authenticate_partner) | **POST** /v1/oauth2/client_credential/accesstoken | Authenticate Partner
*Yapstone::DisbursementsApi* | [**disburse_payment_by_id**](docs/DisbursementsApi.md#disburse_payment_by_id) | **PUT** /v2/disbursements/payment/{paymentId} | Change payment from \"Hold payout\" state to be ready for disbursement
*Yapstone::DisbursementsApi* | [**disburse_transaction_by_id**](docs/DisbursementsApi.md#disburse_transaction_by_id) | **PUT** /v2/disbursements/transaction/{transactionId} | Change transaction from \"Hold payout\" state to be ready for disbursement (payout)
*Yapstone::PaymentsApi* | [**cancel_payment**](docs/PaymentsApi.md#cancel_payment) | **DELETE** /v2/payments/payment/{paymentId} | Cancel Payment by payment Id
*Yapstone::PaymentsApi* | [**cancel_transaction**](docs/PaymentsApi.md#cancel_transaction) | **DELETE** /v2/payments/transaction/{transactionId} | Cancel Transaction by TransactionId
*Yapstone::PaymentsApi* | [**capture_payment**](docs/PaymentsApi.md#capture_payment) | **PATCH** /v2/payments/payment/{paymentId} | Capture a prior authorized payment
*Yapstone::PaymentsApi* | [**create_payment**](docs/PaymentsApi.md#create_payment) | **POST** /v2/payments/payment | Process Payment
*Yapstone::PaymentsApi* | [**get_payment**](docs/PaymentsApi.md#get_payment) | **GET** /v2/payments/payment/{paymentId} | Get with Payment Id
*Yapstone::PaymentsApi* | [**get_transaction**](docs/PaymentsApi.md#get_transaction) | **GET** /v2/payments/transaction/{transactionId} | Get Transaction by Transaction Id
*Yapstone::PaymentsApi* | [**verify_payment_instrument**](docs/PaymentsApi.md#verify_payment_instrument) | **POST** /v2/payments/instrument/verify | Verify payment instrument
*Yapstone::RefundsApi* | [**cancel_refund**](docs/RefundsApi.md#cancel_refund) | **DELETE** /v2/refunds/refund/{refundId} | Cancel Payment by payment Id
*Yapstone::RefundsApi* | [**create_payment_refund**](docs/RefundsApi.md#create_payment_refund) | **POST** /v2/refunds/payment | Create a refund
*Yapstone::RefundsApi* | [**create_transaction_refund**](docs/RefundsApi.md#create_transaction_refund) | **POST** /v2/refunds/transaction | Create a refund
*Yapstone::RefundsApi* | [**get_by_originaltransaction_id**](docs/RefundsApi.md#get_by_originaltransaction_id) | **GET** /v2/refunds/transaction/{transactionId} | Get master Transaction details including all refund details by transaction Id
*Yapstone::RefundsApi* | [**get_refund**](docs/RefundsApi.md#get_refund) | **GET** /v2/refunds/refund/{refundId} | Get master payment details including all refund detail by refund ID.
*Yapstone::RefundsApi* | [**get_refund_by_payment_id**](docs/RefundsApi.md#get_refund_by_payment_id) | **GET** /v2/refunds/payment/{paymentId} | Get master payment details including all refund details by Payment Id.
*Yapstone::SearchApi* | [**search_by_payment_id**](docs/SearchApi.md#search_by_payment_id) | **GET** /v2/search/payment/{paymentId} | Search with Payment Id
*Yapstone::SearchApi* | [**search_by_transaction_id**](docs/SearchApi.md#search_by_transaction_id) | **GET** /v2/search/transaction/{transactionId} | Search with transaction id
*Yapstone::TokenApi* | [**create_token**](docs/TokenApi.md#create_token) | **POST** /v2/token | Create a Token
*Yapstone::TokenApi* | [**lookup_token**](docs/TokenApi.md#lookup_token) | **POST** /v2/token/lookup | Lookup a Token


## Documentation for Models

 - [Yapstone::APM](docs/APM.md)
 - [Yapstone::APMSpecInParameters](docs/APMSpecInParameters.md)
 - [Yapstone::Action](docs/Action.md)
 - [Yapstone::Address](docs/Address.md)
 - [Yapstone::Amount](docs/Amount.md)
 - [Yapstone::AuthResponse](docs/AuthResponse.md)
 - [Yapstone::AuthTokenRequest](docs/AuthTokenRequest.md)
 - [Yapstone::AuthTokenResponse](docs/AuthTokenResponse.md)
 - [Yapstone::BankAccount](docs/BankAccount.md)
 - [Yapstone::BillingAddress](docs/BillingAddress.md)
 - [Yapstone::BookingInfo](docs/BookingInfo.md)
 - [Yapstone::CapturePaymentRequest](docs/CapturePaymentRequest.md)
 - [Yapstone::Card](docs/Card.md)
 - [Yapstone::CardResponse](docs/CardResponse.md)
 - [Yapstone::Consent](docs/Consent.md)
 - [Yapstone::CreditCardAuthResponse](docs/CreditCardAuthResponse.md)
 - [Yapstone::Customer](docs/Customer.md)
 - [Yapstone::CustomerData](docs/CustomerData.md)
 - [Yapstone::CustomerDetails](docs/CustomerDetails.md)
 - [Yapstone::Deposit](docs/Deposit.md)
 - [Yapstone::DepositDetails](docs/DepositDetails.md)
 - [Yapstone::DisburseLineItemsReq](docs/DisburseLineItemsReq.md)
 - [Yapstone::DisburseTransaction](docs/DisburseTransaction.md)
 - [Yapstone::DisburseTransactionReq](docs/DisburseTransactionReq.md)
 - [Yapstone::Disbursement](docs/Disbursement.md)
 - [Yapstone::DisbursementAllOf](docs/DisbursementAllOf.md)
 - [Yapstone::DisbursementDetails](docs/DisbursementDetails.md)
 - [Yapstone::DisbursementRequest](docs/DisbursementRequest.md)
 - [Yapstone::DisbursementRequests](docs/DisbursementRequests.md)
 - [Yapstone::DisbursementResponse](docs/DisbursementResponse.md)
 - [Yapstone::Error](docs/Error.md)
 - [Yapstone::ErrorResponse](docs/ErrorResponse.md)
 - [Yapstone::Fields](docs/Fields.md)
 - [Yapstone::GovIdentification](docs/GovIdentification.md)
 - [Yapstone::Guest](docs/Guest.md)
 - [Yapstone::GuestInfoResponse](docs/GuestInfoResponse.md)
 - [Yapstone::Href](docs/Href.md)
 - [Yapstone::InlineResponse200](docs/InlineResponse200.md)
 - [Yapstone::InstallmentPlan](docs/InstallmentPlan.md)
 - [Yapstone::Instrument](docs/Instrument.md)
 - [Yapstone::InstrumentVerificationResponse](docs/InstrumentVerificationResponse.md)
 - [Yapstone::KYC](docs/KYC.md)
 - [Yapstone::LeaseInfo](docs/LeaseInfo.md)
 - [Yapstone::LineItemDetails](docs/LineItemDetails.md)
 - [Yapstone::MarketplaceData](docs/MarketplaceData.md)
 - [Yapstone::Merketplace](docs/Merketplace.md)
 - [Yapstone::Money](docs/Money.md)
 - [Yapstone::Name](docs/Name.md)
 - [Yapstone::OfferingDetails](docs/OfferingDetails.md)
 - [Yapstone::OrderTransactions](docs/OrderTransactions.md)
 - [Yapstone::Payment](docs/Payment.md)
 - [Yapstone::PaymentCancelResponse](docs/PaymentCancelResponse.md)
 - [Yapstone::PaymentCancelTransactionResponse](docs/PaymentCancelTransactionResponse.md)
 - [Yapstone::PaymentDetails](docs/PaymentDetails.md)
 - [Yapstone::PaymentInstrument](docs/PaymentInstrument.md)
 - [Yapstone::PaymentInstrumentCard](docs/PaymentInstrumentCard.md)
 - [Yapstone::PaymentInstrumentResponse](docs/PaymentInstrumentResponse.md)
 - [Yapstone::PaymentPayment](docs/PaymentPayment.md)
 - [Yapstone::PaymentPaymentAllOf](docs/PaymentPaymentAllOf.md)
 - [Yapstone::PaymentResponse](docs/PaymentResponse.md)
 - [Yapstone::Phone](docs/Phone.md)
 - [Yapstone::ProcessPayment](docs/ProcessPayment.md)
 - [Yapstone::PropertyInfo](docs/PropertyInfo.md)
 - [Yapstone::PropertyInfoResponse](docs/PropertyInfoResponse.md)
 - [Yapstone::RefundAction](docs/RefundAction.md)
 - [Yapstone::RefundCancelResponse](docs/RefundCancelResponse.md)
 - [Yapstone::RefundCancelTransactionResponse](docs/RefundCancelTransactionResponse.md)
 - [Yapstone::RefundRequest](docs/RefundRequest.md)
 - [Yapstone::RefundResponse](docs/RefundResponse.md)
 - [Yapstone::RefundStatus](docs/RefundStatus.md)
 - [Yapstone::RefundTransactions](docs/RefundTransactions.md)
 - [Yapstone::RentalInfo](docs/RentalInfo.md)
 - [Yapstone::Renter](docs/Renter.md)
 - [Yapstone::Resolution](docs/Resolution.md)
 - [Yapstone::Result](docs/Result.md)
 - [Yapstone::RiskStatus](docs/RiskStatus.md)
 - [Yapstone::SanctionedEntities](docs/SanctionedEntities.md)
 - [Yapstone::SearchPaymentResponse](docs/SearchPaymentResponse.md)
 - [Yapstone::StackTraceElement](docs/StackTraceElement.md)
 - [Yapstone::Status](docs/Status.md)
 - [Yapstone::Throwable](docs/Throwable.md)
 - [Yapstone::ToEntityRef](docs/ToEntityRef.md)
 - [Yapstone::Token](docs/Token.md)
 - [Yapstone::TokenReq](docs/TokenReq.md)
 - [Yapstone::TokenRequest](docs/TokenRequest.md)
 - [Yapstone::TokenResponse](docs/TokenResponse.md)
 - [Yapstone::Transaction](docs/Transaction.md)
 - [Yapstone::TransactionResponse](docs/TransactionResponse.md)
 - [Yapstone::Triggers](docs/Triggers.md)
 - [Yapstone::VacationRentalInfo](docs/VacationRentalInfo.md)
 - [Yapstone::VacationRentalInfoRequest](docs/VacationRentalInfoRequest.md)
 - [Yapstone::VerifyInstrumentRequest](docs/VerifyInstrumentRequest.md)


## Documentation for Authorization


### Bearer

- **Type**: Bearer authentication (JWT)

