# Yapstone::DisbursementsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**disburse_payment_by_id**](DisbursementsApi.md#disburse_payment_by_id) | **PUT** /v2/disbursements/payment/{paymentId} | Change payment from \&quot;Hold payout\&quot; state to be ready for disbursement
[**disburse_transaction_by_id**](DisbursementsApi.md#disburse_transaction_by_id) | **PUT** /v2/disbursements/transaction/{transactionId} | Change transaction from \&quot;Hold payout\&quot; state to be ready for disbursement (payout)



## disburse_payment_by_id

> PaymentResponse disburse_payment_by_id(authorization, x_yapstone_ip_address, payment_id, disbursement_requests, opts)

Change payment from \"Hold payout\" state to be ready for disbursement

Disburse payment

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::DisbursementsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
payment_id = 'payment_id_example' # String | 
disbursement_requests = Yapstone::DisbursementRequests.new # DisbursementRequests | 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Change payment from \"Hold payout\" state to be ready for disbursement
  result = api_instance.disburse_payment_by_id(authorization, x_yapstone_ip_address, payment_id, disbursement_requests, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling DisbursementsApi->disburse_payment_by_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **payment_id** | **String**|  | 
 **disbursement_requests** | [**DisbursementRequests**](DisbursementRequests.md)|  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**PaymentResponse**](PaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## disburse_transaction_by_id

> PaymentResponse disburse_transaction_by_id(authorization, x_yapstone_ip_address, transaction_id, disburse_transaction_req, opts)

Change transaction from \"Hold payout\" state to be ready for disbursement (payout)

Provide the transaction ID for the transaction where you want to shift state so that money can finally be paid out (disbursed). 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::DisbursementsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
transaction_id = 'transaction_id_example' # String | The identification number for the transaction you want to disburse. 
disburse_transaction_req = Yapstone::DisburseTransactionReq.new # DisburseTransactionReq | 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Change transaction from \"Hold payout\" state to be ready for disbursement (payout)
  result = api_instance.disburse_transaction_by_id(authorization, x_yapstone_ip_address, transaction_id, disburse_transaction_req, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling DisbursementsApi->disburse_transaction_by_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **transaction_id** | **String**| The identification number for the transaction you want to disburse.  | 
 **disburse_transaction_req** | [**DisburseTransactionReq**](DisburseTransactionReq.md)|  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**PaymentResponse**](PaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

