# Yapstone::PaymentsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**cancel_payment**](PaymentsApi.md#cancel_payment) | **DELETE** /v2/payments/payment/{paymentId} | Cancel Payment by payment Id
[**cancel_transaction**](PaymentsApi.md#cancel_transaction) | **DELETE** /v2/payments/transaction/{transactionId} | Cancel Transaction by TransactionId
[**capture_payment**](PaymentsApi.md#capture_payment) | **PATCH** /v2/payments/payment/{paymentId} | Capture a prior authorized payment
[**create_payment**](PaymentsApi.md#create_payment) | **POST** /v2/payments/payment | Process Payment
[**get_payment**](PaymentsApi.md#get_payment) | **GET** /v2/payments/payment/{paymentId} | Get with Payment Id
[**get_transaction**](PaymentsApi.md#get_transaction) | **GET** /v2/payments/transaction/{transactionId} | Get Transaction by Transaction Id
[**verify_payment_instrument**](PaymentsApi.md#verify_payment_instrument) | **POST** /v2/payments/instrument/verify | Verify payment instrument



## cancel_payment

> PaymentCancelResponse cancel_payment(authorization, x_yapstone_ip_address, payment_id, opts)

Cancel Payment by payment Id

Use a DELETE request to send a payment ID to this endpoint in order to cancel the payment. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | Ip Address of the client
payment_id = 'payment_id_example' # String | paymentId
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Cancel Payment by payment Id
  result = api_instance.cancel_payment(authorization, x_yapstone_ip_address, payment_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->cancel_payment: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| Ip Address of the client | 
 **payment_id** | **String**| paymentId | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**PaymentCancelResponse**](PaymentCancelResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## cancel_transaction

> PaymentCancelTransactionResponse cancel_transaction(authorization, x_yapstone_ip_address, transaction_id, opts)

Cancel Transaction by TransactionId

Use a transaction identifier to cancel a transaction. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | Ip Address of the client
transaction_id = 'transaction_id_example' # String | The transaction ID for the transaction you would like to cancel. 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Cancel Transaction by TransactionId
  result = api_instance.cancel_transaction(authorization, x_yapstone_ip_address, transaction_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->cancel_transaction: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| Ip Address of the client | 
 **transaction_id** | **String**| The transaction ID for the transaction you would like to cancel.  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**PaymentCancelTransactionResponse**](PaymentCancelTransactionResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## capture_payment

> PaymentResponse capture_payment(authorization, x_yapstone_ip_address, payment_id, opts)

Capture a prior authorized payment

Capture a prior authorized payment. This endpoint is used after a payment is authorized. Once a payment is authorized, you must capture it so that money can be transferred from the customer's account to the merchant's account. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | Ip Address of the client
payment_id = 'payment_id_example' # String | The payment ID associated with the payment. You can use this to retrieve a payment or chance its status. 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example', # String | Device Finger Print Id
  capture_payment_request: Yapstone::CapturePaymentRequest.new # CapturePaymentRequest | 
}

begin
  #Capture a prior authorized payment
  result = api_instance.capture_payment(authorization, x_yapstone_ip_address, payment_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->capture_payment: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| Ip Address of the client | 
 **payment_id** | **String**| The payment ID associated with the payment. You can use this to retrieve a payment or chance its status.  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 
 **capture_payment_request** | [**CapturePaymentRequest**](CapturePaymentRequest.md)|  | [optional] 

### Return type

[**PaymentResponse**](PaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## create_payment

> PaymentResponse create_payment(authorization, x_yapstone_ip_address, process_payment, opts)

Process Payment

The payment endpoint lets you create a payment and send information identifying the customer device the payment comes from. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | This is the IP address of the client. 
process_payment = Yapstone::ProcessPayment.new # ProcessPayment | processPayment
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | A device fingerprint is information gathered about the hardware and software of a website visitor combined with browser information. The fingerprint can be used to help retrieve particular sessions later, and it provides details about whoever is making a payment. 
}

begin
  #Process Payment
  result = api_instance.create_payment(authorization, x_yapstone_ip_address, process_payment, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->create_payment: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| This is the IP address of the client.  | 
 **process_payment** | [**ProcessPayment**](ProcessPayment.md)| processPayment | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| A device fingerprint is information gathered about the hardware and software of a website visitor combined with browser information. The fingerprint can be used to help retrieve particular sessions later, and it provides details about whoever is making a payment.  | [optional] 

### Return type

[**PaymentResponse**](PaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_payment

> PaymentResponse get_payment(authorization, x_yapstone_ip_address, payment_id, opts)

Get with Payment Id

This endpoint lets you send a GET request containing a payment ID. The associated payment is returned to you in the response. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
payment_id = 'payment_id_example' # String | paymentId
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Get with Payment Id
  result = api_instance.get_payment(authorization, x_yapstone_ip_address, payment_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->get_payment: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **payment_id** | **String**| paymentId | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**PaymentResponse**](PaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_transaction

> OrderTransactions get_transaction(authorization, x_yapstone_ip_address, transaction_id, opts)

Get Transaction by Transaction Id

Retrieve information about a specific transaction. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
transaction_id = 'transaction_id_example' # String | The transaction identifier for the transaction you want to retrieve details about. 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Get Transaction by Transaction Id
  result = api_instance.get_transaction(authorization, x_yapstone_ip_address, transaction_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->get_transaction: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **transaction_id** | **String**| The transaction identifier for the transaction you want to retrieve details about.  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**OrderTransactions**](OrderTransactions.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## verify_payment_instrument

> InstrumentVerificationResponse verify_payment_instrument(authorization, x_yapstone_ip_address, verify_instrument_request, opts)

Verify payment instrument

Use this endpoint to verify that a customer's payment instrument is valid and associated with them. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::PaymentsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
verify_instrument_request = Yapstone::VerifyInstrumentRequest.new # VerifyInstrumentRequest | verifyInstrumentRequest
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Verify payment instrument
  result = api_instance.verify_payment_instrument(authorization, x_yapstone_ip_address, verify_instrument_request, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling PaymentsApi->verify_payment_instrument: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **verify_instrument_request** | [**VerifyInstrumentRequest**](VerifyInstrumentRequest.md)| verifyInstrumentRequest | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**InstrumentVerificationResponse**](InstrumentVerificationResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

