# Yapstone::RefundsApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**cancel_refund**](RefundsApi.md#cancel_refund) | **DELETE** /v2/refunds/refund/{refundId} | Cancel Payment by payment Id
[**create_payment_refund**](RefundsApi.md#create_payment_refund) | **POST** /v2/refunds/payment | Create a refund
[**create_transaction_refund**](RefundsApi.md#create_transaction_refund) | **POST** /v2/refunds/transaction | Create a refund
[**get_by_originaltransaction_id**](RefundsApi.md#get_by_originaltransaction_id) | **GET** /v2/refunds/transaction/{transactionId} | Get master Transaction details including all refund details by transaction Id
[**get_refund**](RefundsApi.md#get_refund) | **GET** /v2/refunds/refund/{refundId} | Get master payment details including all refund detail by refund ID.
[**get_refund_by_payment_id**](RefundsApi.md#get_refund_by_payment_id) | **GET** /v2/refunds/payment/{paymentId} | Get master payment details including all refund details by Payment Id.



## cancel_refund

> RefundCancelResponse cancel_refund(authorization, x_yapstone_ip_address, refund_id, opts)

Cancel Payment by payment Id

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::RefundsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | Ip Address of the client
refund_id = 'refund_id_example' # String | refundId
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | X-Yapstone-Trace-Id
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Cancel Payment by payment Id
  result = api_instance.cancel_refund(authorization, x_yapstone_ip_address, refund_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling RefundsApi->cancel_refund: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| Ip Address of the client | 
 **refund_id** | **String**| refundId | 
 **x_yapstone_trace_id** | **String**| X-Yapstone-Trace-Id | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**RefundCancelResponse**](RefundCancelResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## create_payment_refund

> RefundResponse create_payment_refund(authorization, x_yapstone_ip_address, refund_request, opts)

Create a refund

Create a refund for a payment that was processed

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::RefundsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
refund_request = Yapstone::RefundRequest.new # RefundRequest | 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Create a refund
  result = api_instance.create_payment_refund(authorization, x_yapstone_ip_address, refund_request, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling RefundsApi->create_payment_refund: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **refund_request** | [**RefundRequest**](RefundRequest.md)|  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**RefundResponse**](RefundResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## create_transaction_refund

> RefundResponse create_transaction_refund(authorization, x_yapstone_ip_address, transaction, opts)

Create a refund

Use this end point to kick off a refund for transaction. If you've already captured the transaction, this will result in a refund of the amount captured and the details of that refund will be returned in the response body. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::RefundsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
transaction = Yapstone::Transaction.new # Transaction | 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example' # String | Device Finger Print Id
}

begin
  #Create a refund
  result = api_instance.create_transaction_refund(authorization, x_yapstone_ip_address, transaction, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling RefundsApi->create_transaction_refund: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **transaction** | [**Transaction**](Transaction.md)|  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 

### Return type

[**RefundResponse**](RefundResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_by_originaltransaction_id

> TransactionResponse get_by_originaltransaction_id(authorization, x_yapstone_ip_address, transaction_id, opts)

Get master Transaction details including all refund details by transaction Id

Transactions are nested inside payments. Master transactions are nested inside the master payment. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::RefundsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
transaction_id = 'transaction_id_example' # String | transactionId
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Get master Transaction details including all refund details by transaction Id
  result = api_instance.get_by_originaltransaction_id(authorization, x_yapstone_ip_address, transaction_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling RefundsApi->get_by_originaltransaction_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **transaction_id** | **String**| transactionId | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**TransactionResponse**](TransactionResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_refund

> RefundResponse get_refund(authorization, x_yapstone_ip_address, refund_id, opts)

Get master payment details including all refund detail by refund ID.

A master payment is the initial payment that all other payment details and transactions tied to that payment connect to. You can use a refund ID to retrieve master payment information. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::RefundsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
refund_id = 'refund_id_example' # String | refundId
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Get master payment details including all refund detail by refund ID.
  result = api_instance.get_refund(authorization, x_yapstone_ip_address, refund_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling RefundsApi->get_refund: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **refund_id** | **String**| refundId | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**RefundResponse**](RefundResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_refund_by_payment_id

> RefundResponse get_refund_by_payment_id(authorization, x_yapstone_ip_address, payment_id, opts)

Get master payment details including all refund details by Payment Id.

A master payment is the initial payment that all other payment details and transactions tied to that payment connect to. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::RefundsApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
payment_id = 'payment_id_example' # String | paymentId
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Get master payment details including all refund details by Payment Id.
  result = api_instance.get_refund_by_payment_id(authorization, x_yapstone_ip_address, payment_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling RefundsApi->get_refund_by_payment_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **payment_id** | **String**| paymentId | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**RefundResponse**](RefundResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

