# Yapstone::SearchApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**search_by_payment_id**](SearchApi.md#search_by_payment_id) | **GET** /v2/search/payment/{paymentId} | Search with Payment Id
[**search_by_transaction_id**](SearchApi.md#search_by_transaction_id) | **GET** /v2/search/transaction/{transactionId} | Search with transaction id



## search_by_payment_id

> SearchPaymentResponse search_by_payment_id(authorization, x_yapstone_ip_address, payment_id, opts)

Search with Payment Id

Use this endpoint to search for a payment by payment ID. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::SearchApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
payment_id = 'payment_id_example' # String | 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Search with Payment Id
  result = api_instance.search_by_payment_id(authorization, x_yapstone_ip_address, payment_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling SearchApi->search_by_payment_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **payment_id** | **String**|  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**SearchPaymentResponse**](SearchPaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## search_by_transaction_id

> SearchPaymentResponse search_by_transaction_id(authorization, x_yapstone_fpsid, x_yapstone_ip_address, transaction_id, opts)

Search with transaction id

Use this endpoint to search for particular transactions using their transaction ID. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::SearchApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_fpsid = 'x_yapstone_fpsid_example' # String | Device Finger Print Id
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
transaction_id = 'transaction_id_example' # String | 
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example' # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
}

begin
  #Search with transaction id
  result = api_instance.search_by_transaction_id(authorization, x_yapstone_fpsid, x_yapstone_ip_address, transaction_id, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling SearchApi->search_by_transaction_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **transaction_id** | **String**|  | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 

### Return type

[**SearchPaymentResponse**](SearchPaymentResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

