# Yapstone::TokenApi

All URIs are relative to *https://api-prod-sandbox.yapstone.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_token**](TokenApi.md#create_token) | **POST** /v2/token | Create a Token
[**lookup_token**](TokenApi.md#lookup_token) | **POST** /v2/token/lookup | Lookup a Token



## create_token

> Token create_token(authorization, x_yapstone_ip_address, opts)

Create a Token

Create a token to make a payment. In your request you specify the type of instrument and you are returned a token for that instrument in the response. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::TokenApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. 
  x_yapstone_fpsid: 'x_yapstone_fpsid_example', # String | Device Finger Print Id
  token_request: Yapstone::TokenRequest.new # TokenRequest | 
}

begin
  #Create a Token
  result = api_instance.create_token(authorization, x_yapstone_ip_address, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling TokenApi->create_token: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.  | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 
 **token_request** | [**TokenRequest**](TokenRequest.md)|  | [optional] 

### Return type

[**Token**](Token.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## lookup_token

> TokenResponse lookup_token(authorization, x_yapstone_ip_address, opts)

Lookup a Token

Lookup a token to make a payment. Submit the token ID to retrieve details about the token. 

### Example

```ruby
# load the gem
require 'yapstone-payments'
# setup authorization
Yapstone.configure do |config|
  # Configure Bearer authorization (JWT): Bearer
  config.access_token = 'YOUR_BEARER_TOKEN'
end

api_instance = Yapstone::TokenApi.new
authorization = 'authorization_example' # String | Authorization
x_yapstone_ip_address = 'x_yapstone_ip_address_example' # String | IP Address of the client
opts = {
  x_yapstone_trace_id: 'x_yapstone_trace_id_example', # String | Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string.
  x_yapstone_fpsid: 'x_yapstone_fpsid_example', # String | Device Finger Print Id
  token: Yapstone::Token.new # Token | 
}

begin
  #Lookup a Token
  result = api_instance.lookup_token(authorization, x_yapstone_ip_address, opts)
  p result
rescue Yapstone::ApiError => e
  puts "Exception when calling TokenApi->lookup_token: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| Authorization | 
 **x_yapstone_ip_address** | **String**| IP Address of the client | 
 **x_yapstone_trace_id** | **String**| Optionally provide a unique identifier for this request, for use later if you need to debug this request with Yapstone support. Can be any arbitrary string. | [optional] 
 **x_yapstone_fpsid** | **String**| Device Finger Print Id | [optional] 
 **token** | [**Token**](Token.md)|  | [optional] 

### Return type

[**TokenResponse**](TokenResponse.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

